declare const module: {
    namespaced: boolean;
    state: {
        datasets: never[];
        loading: boolean;
        searchParameters: {
            query: string;
            limit: number;
            offset: number;
            facets: {};
            facetOperator: string;
            facetGroupOperator: string;
            dataServices: string;
            superCatalogue: undefined;
            datasetGeoBounds: undefined;
            sort: string;
        };
        availableFacets: never[];
        page: number;
        pageCount: number;
        datasetsCount: number;
        dataScope: undefined;
        minScoring: undefined;
        scoringFacets: {
            id: string;
            title: string;
            count: number;
            minScoring: number;
            maxScoring: number;
        }[];
    };
    actions: {
        /**
         * @description Load all datasets matching the given parameters.
         * @param commit
         * @param state
         * @param options {Object} - Given search parameters
         * @param options.query {String} - The given query string
         * @param options.facets {Array} - The active facets
         * @param options.limit {Number} - The maximum amount of datasets to fetch
         * @param options.page {Number} - The current page
         * @param options.sort {String} - The sort method to use
         * @param options.geoBounds {Array} - The given bounds to setup a spatial search for
         * @param options.append {Boolean} - Decides whether current datasets in state will be replaced or fetched datasets appended.
         */
        loadDatasets({ commit, state }: {
            commit: any;
            state: any;
        }, { locale, query, limit, page, sort, facetOperator, facetGroupOperator, dataServices, facets, geoBounds, minScoring, dataScope, append, }: {
            locale: any;
            query?: any;
            limit?: any;
            page?: any;
            sort?: any;
            facetOperator?: any;
            facetGroupOperator?: any;
            dataServices?: any;
            facets?: any;
            geoBounds?: any;
            minScoring?: any;
            dataScope?: any;
            append?: boolean | undefined;
        }): Promise<unknown>;
        /**
       * @description Loads more datasets.
       * @param commit
       * @param state
       * @param {number} amount - The amount of datasets to add.
       */
        loadSingleDataset({ commit }: {
            commit: any;
        }, id: any): Promise<unknown>;
        /**
         * @description Loads more datasets.
         * @param commit
         * @param state
         * @param {number} amount - The amount of datasets to add.
         */
        loadAdditionalDatasets({ commit, state }: {
            commit: any;
            state: any;
        }): void;
        /**
         * @description Autocomplete a query String by using a autocompletion service
         * @param commit
         * @param q {String} The Query to autocomplete
         */
        autocompleteQuery({ commit }: {
            commit: any;
        }, q: any): Promise<unknown> | undefined;
        /**
         * @description Replace the current state facets by the given facets
         * @param commit
         * @param facets {Array} - The given facets
         */
        setFacets({ commit }: {
            commit: any;
        }, facets: any): void;
        /**
         * @description Add the given facet to the states facets.
         * @param commit
         * @param params {Object} - The wrapped action parameters.
         * @param params.field {String} - The field of the given facet
         * @param params.facet {String} - The facet to add
         */
        addFacet({ commit }: {
            commit: any;
        }, { field, facet }: {
            field: any;
            facet: any;
        }): void;
        /**
         * @description Remove the given facet from the states facets.
         * @param commit
         * @param params {Object} - The wrapped action parameters.
         * @param params.field {String} - The field of the given facet
         * @param params.facet {String} - The facet to remove
         */
        removeFacet({ commit }: {
            commit: any;
        }, { field, facet }: {
            field: any;
            facet: any;
        }): void;
        /**
         * @description Remove the given facet from the states facets.
         * @param commit
         * @param operator {String} - The facet operator to set. Possible Operators : ['AND', 'OR'].
         */
        setFacetOperator({ commit }: {
            commit: any;
        }, operator: any): void;
        /**
         * @description Remove the given facet from the states facets.
         * @param commit
         * @param operator {String} - The facet operator to set. Possible Operators : ['AND', 'OR'].
         */
        setFacetGroupOperator({ commit }: {
            commit: any;
        }, operator: any): void;
        /**
         * @description Remove the given facet from the states facets.
         * @param commit
         * @param operator {String} - The data services to set. Possible Operators : ['true', 'false'].
         */
        setDataServices({ commit }: {
            commit: any;
        }, dataServices: any): void;
        /**
         * @description Remove the given facet from the states facets.
         * @param commit
         * @param operator {String} - Only Erpd data. Possible Operators : ['true', 'false'].
         */
        setSuperCatalogue_DEPRECATED({ commit }: {
            commit: any;
        }, superCatalogue: any): void;
        setPage({ commit }: {
            commit: any;
        }, page: any): void;
        setPageCount({ commit }: {
            commit: any;
        }, count: any): void;
        setQuery({ commit }: {
            commit: any;
        }, query: any): void;
        setSort({ commit }: {
            commit: any;
        }, sort: any): void;
        setLimit({ commit }: {
            commit: any;
        }, amount?: number): void;
        setDatasetGeoBounds({ commit }: {
            commit: any;
        }, bounds: any): void;
        setLoading({ commit }: {
            commit: any;
        }, isLoading: any): void;
        setMinScoring({ commit }: {
            commit: any;
        }, minScoring: any): void;
        setDataScope({ commit }: {
            commit: any;
        }, dataScope: any): void;
        setAvailableFacets({ commit }: {
            commit: any;
        }, facets: any): void;
        setScoringCount({ commit }: {
            commit: any;
        }, count: any): void;
        setDatasetsCount({ commit }: {
            commit: any;
        }, count: any): void;
        setDatasets({ commit }: {
            commit: any;
        }, datasets: any): void;
    };
    mutations: {
        SET_DATASETS(state: any, data: any): void;
        ADD_DATASETS(state: any, data: any): void;
        SET_LIMIT(state: any, limit: any): void;
        SET_OFFSET(state: any, offset: any): void;
        SET_FACETS(state: any, facets: any): void;
        ADD_FACET(state: any, { field, facet }: {
            field: any;
            facet: any;
        }): void;
        REMOVE_FACET(state: any, { field, facet }: {
            field: any;
            facet: any;
        }): void;
        SET_DATASET_GEO_BOUNDS(state: any, bounds: any): void;
        SET_AVAILABLE_FACETS(state: any, facets: any): void;
        SET_SCORING_COUNT(state: any, scoringCount: any): void;
        SET_DATASETS_COUNT(state: any, datasetsCount: any): void;
        SET_FACET_OPERATOR(state: any, operator: any): void;
        SET_FACET_GROUP_OPERATOR(state: any, operator: any): void;
        SET_DATA_SERVICES(state: any, dataServices: any): void;
        SET_SUPER_CATALOGUE(state: any, superCatalogue: any): void;
        SET_PAGE(state: any, page: any): void;
        SET_PAGE_COUNT(state: any, count: any): void;
        SET_QUERY(state: any, query: any): void;
        SET_SORT(state: any, sort: any): void;
        SET_LOADING(state: any, isLoading: any): void;
        SET_MIN_SCORING(state: any, minScoring: any): void;
        SET_DATA_SCOPE(state: any, dataScope: any): void;
    };
    getters: {
        getDatasets: (state: any) => any;
        getDatasetsCount: (state: any) => any;
        getQuery: (state: any) => any;
        getLimit: (state: any) => any;
        getLoading: (state: any) => any;
        getOffset: (state: any) => any;
        getFacets: (state: any) => any;
        getFacetOperator: (state: any) => any;
        getFacetGroupOperator: (state: any) => any;
        getDataServices: (state: any) => any;
        getSuperCatalogue_DEPRECATED: (state: any) => any;
        getDatasetGeoBounds: (state: any) => any;
        getAvailableFacets: (state: any) => any;
        getAllAvailableFacets: (state: any) => any[];
        getPage: (state: any) => any;
        getPageCount: (state: any) => any;
        getSort: (state: any) => any;
        getMinScoring: (state: any) => any;
        getScoringFacets: (state: any) => any;
        getDataScope: (state: any) => any;
    };
};
export default module;
